pub struct PartitionEntry { /* private fields */ }Expand description
Represents a single partition entry.
Implementations
Sourceimpl PartitionEntry
impl PartitionEntry
Sourcepub fn raw_subtype(&self) -> u8
pub fn raw_subtype(&self) -> u8
The partition sub-type in raw representation.
Sourcepub fn label_as_str(&self) -> &str
pub fn label_as_str(&self) -> &str
The label of the partition as &str.
Sourcepub fn flags(&self) -> u32
pub fn flags(&self) -> u32
Raw flags of this partition. You probably want to use Self::is_read_only and Self::is_encrypted instead.
Sourcepub fn is_read_only(&self) -> bool
pub fn is_read_only(&self) -> bool
If the partition is read only.
Sourcepub fn is_encrypted(&self) -> bool
pub fn is_encrypted(&self) -> bool
If the partition is encrypted.
This is the flag from the partition table. If flash encryption is enabled certain partition types are encrypted regardless of this.
Sourcepub fn partition_type(&self) -> PartitionType
pub fn partition_type(&self) -> PartitionType
The partition type (type and sub-type).
Sourcepub fn as_flash_region<'a, 'd>(
self,
flash: &'a mut FlashStorage<'d>,
) -> FlashRegion<'a, 'd>
pub fn as_flash_region<'a, 'd>( self, flash: &'a mut FlashStorage<'d>, ) -> FlashRegion<'a, 'd>
Provides a “view” into the partition allowing to read/write the
partition contents using the given FlashStorage.
Sourcepub fn sha256(&self, flash: &mut FlashStorage<'_>) -> Result<[u8; 32], Error>
pub fn sha256(&self, flash: &mut FlashStorage<'_>) -> Result<[u8; 32], Error>
Calculate the SHA-256 digest of this partition.
- App / bootloader with appended hash: return that digest after verifying it
- App / bootloader without appended hash: hash the image (not the whole partition)
- Other types: hash the entire partition
For app images this is the validation hash (shown by
esptool.py image-info), not the ELF file SHA-256 stored in
crate::EspAppDesc.